#!/usr/bin/python3
import mdpeditor.runner

sys.exit(mdpeditor.runner.run())
